@@ -1,18 +1,20 @@
+"""This module contains helpers for generating MythX analysis payloads."""
+
 import logging
-import sys
-from glob import glob
 from os.path import abspath, commonpath
 from pathlib import Path
-from typing import Dict, List, Optional, Tuple, Union
+from typing import Dict
 
 import click
 
-from mythx_cli.payload import generate_solidity_payload
-
-RGLOB_BLACKLIST = ["node_modules"]
 LOGGER = logging.getLogger("mythx-cli")
 
 
+def delete_absolute_prefix(path: str, prefix: str):
+    absolute = Path(path).absolute()
+    return str(absolute).replace(prefix, "")
+
+
 def sanitize_paths(job: Dict) -> Dict:
     """Remove the common prefix from paths.
 
@@ -55,13 +57,13 @@ def sanitize_paths(job: Dict) -> Dict:
         LOGGER.debug("One source list item detected - trimming by CWD prefix")
         prefix = commonpath(source_list + [str(Path.cwd())]) + "/"
 
-    LOGGER.debug(f"Trimming source list: {', '.join(source_list)}")
-    sanitized_source_list = [s.replace(prefix, "") for s in source_list]
+    LOGGER.debug(f"Trimming {prefix} from source list: {', '.join(source_list)}")
+    sanitized_source_list = [delete_absolute_prefix(s, prefix) for s in source_list]
     job["source_list"] = sanitized_source_list
     LOGGER.debug(f"Trimmed source list: {', '.join(sanitized_source_list)}")
     if job.get("main_source") is not None:
         LOGGER.debug(f"Trimming main source path {job['main_source']}")
-        job["main_source"] = job["main_source"].replace(prefix, "")
+        job["main_source"] = delete_absolute_prefix(job["main_source"], prefix)
         LOGGER.debug(f"Trimmed main source path {job['main_source']}")
     for name in list(job.get("sources", {})):
         data = job["sources"].pop(name)
@@ -73,14 +75,16 @@ def sanitize_paths(job: Dict) -> Dict:
                     f"Skipping sanitization: {ast_key} -> absolutePath not defined"
                 )
                 continue
-            sanitized_absolute = data[ast_key]["absolutePath"].replace(prefix, "")
+            sanitized_absolute = delete_absolute_prefix(
+                data[ast_key]["absolutePath"], prefix
+            )
             LOGGER.debug(
                 f"Setting sanitized {ast_key} -> absolutePath to {sanitized_absolute}"
             )
             data[ast_key]["absolutePath"] = sanitized_absolute
 
         # replace source key names
-        sanitized_source_name = name.replace(prefix, "")
+        sanitized_source_name = delete_absolute_prefix(name, prefix)
         LOGGER.debug(f"Setting sanitized source name {sanitized_source_name}")
         job["sources"][sanitized_source_name] = data
 
@@ -132,83 +136,3 @@ def is_valid_job(job) -> bool:
         )
 
     return valid
-
-
-def find_truffle_artifacts(project_dir: Union[str, Path]) -> Optional[List[str]]:
-    """Look for a Truffle build folder and return all relevant JSON artifacts.
-
-    This function will skip the Migrations.json file and return all other files
-    under :code:`<project-dir>/build/contracts/`. If no files were found,
-    :code:`None` is returned.
-
-    :param project_dir: The base directory of the Truffle project
-    :return: Files under :code:`<project-dir>/build/contracts/` or :code:`None`
-    """
-
-    output_pattern = Path(project_dir) / "build" / "contracts" / "*.json"
-    artifact_files = list(glob(str(output_pattern.absolute())))
-    if not artifact_files:
-        LOGGER.debug(f"No truffle artifacts found in pattern {output_pattern}")
-        return None
-
-    LOGGER.debug("Returning results without Migrations.json")
-    return [f for f in artifact_files if not f.endswith("Migrations.json")]
-
-
-def find_solidity_files(project_dir: str) -> Optional[List[str]]:
-    """Return all Solidity files in the given directory.
-
-    This will match all files with the `.sol` extension.
-
-    :param project_dir: The directory to search in
-    :return: Solidity files in `project_dir` or `None`
-    """
-
-    output_pattern = Path(project_dir)
-    artifact_files = [str(x) for x in output_pattern.rglob("*.sol")]
-    if not artifact_files:
-        LOGGER.debug(f"No truffle artifacts found in pattern {output_pattern}")
-        return None
-
-    LOGGER.debug(f"Filtering results by rglob blacklist {RGLOB_BLACKLIST}")
-    return [af for af in artifact_files if all((b not in af for b in RGLOB_BLACKLIST))]
-
-
-def walk_solidity_files(
-    ctx,
-    solc_version: str,
-    base_path: Optional[str] = None,
-    remappings: Tuple[str] = None,
-) -> List[Dict]:
-    """Aggregate all Solidity files in the given base path.
-
-    Given a base path, this function will recursively walk through the filesystem
-    and aggregate all Solidity files it comes across. The resulting job list will
-    contain all the Solidity payloads (optionally compiled), ready for submission.
-
-    :param ctx: :param ctx: Click context holding group-level parameters
-    :param solc_version: The solc version to use for Solidity compilation
-    :param base_path: The base path to walk through from
-    :param remappings: Import remappings to pass to solcx
-    :return:
-    """
-
-    jobs = []
-    remappings = remappings or []
-    LOGGER.debug(f"Received {len(remappings)} import remappings")
-    walk_path = Path(base_path) if base_path else Path.cwd()
-    LOGGER.debug(f"Walking for sol files under {walk_path}")
-    files = find_solidity_files(walk_path)
-    consent = ctx["yes"] or click.confirm(
-        "Found {} Solidity file(s) before filtering. Continue?".format(len(files))
-    )
-    if not consent:
-        LOGGER.debug("User consent not given - exiting")
-        sys.exit(0)
-    LOGGER.debug(f"Found Solidity files to submit: {', '.join(files)}")
-    for file in files:
-        LOGGER.debug(f"Generating Solidity payload for {file}")
-        jobs.append(
-            generate_solidity_payload(file, solc_version, remappings=remappings)
-        )
-    return jobs
